@@ -24,7 +24,7 @@ test_that("Array [+, as.numeric]",
   b <- parm(array(2:7, 2:3), name = "b")
 
   # Create test expression
-  c <- cg.sum(a + as.numeric(b))
+  c <- cg.sum(a + cg.as.numeric(b))
 
   # Calculate gradients
   grads <- gradients(c, run(c))
@@ -44,7 +44,7 @@ test_that("Array [-, as.numeric]",
   b <- parm(array(2:7, 2:3), name = "b")
 
   # Create test expression
-  c <- cg.sum(a - as.numeric(b))
+  c <- cg.sum(a - cg.as.numeric(b))
 
   # Calculate gradients
   grads <- gradients(c, run(c))
@@ -64,7 +64,7 @@ test_that("Array [*, as.numeric]",
   b <- parm(array(2:7, 2:3), name = "b")
 
   # Create test expression
-  c <- cg.sum(a * as.numeric(b))
+  c <- cg.sum(a * cg.as.numeric(b))
 
   # Calculate gradients
   grads <- gradients(c, run(c))
@@ -84,7 +84,7 @@ test_that("Array [/, as.numeric]",
   b <- parm(array(2:7, 2:3), name = "b")
 
   # Create test expression
-  c <- cg.sum(as.numeric(b) / a)
+  c <- cg.sum(cg.as.numeric(b) / a)
 
   # Calculate gradients
   grads <- gradients(c, run(c))
@@ -104,7 +104,7 @@ test_that("Array [^, as.numeric]",
   b <- parm(array(2:7, 2:3), name = "b")
 
   # Create test expression
-  c <- cg.sum(a ^ as.numeric(b))
+  c <- cg.sum(a ^ cg.as.numeric(b))
 
   # Calculate gradients
   grads <- gradients(c, run(c))
@@ -124,7 +124,7 @@ test_that("Array [ln, as.numeric]",
   b <- parm(array(2:7, 2:3), name = "b")
 
   # Create test expression
-  c <- cg.sum(a * cg.ln(as.numeric(b)))
+  c <- cg.sum(a * cg.ln(cg.as.numeric(b)))
 
   # Calculate gradients
   grads <- gradients(c, run(c))
@@ -144,7 +144,7 @@ test_that("Array [pmax, as.numeric]",
   b <- parm(array(2:7, 2:3), name = "b")
 
   # Create test expression
-  c <- cg.sum(cg.pmax(a, as.numeric(b)))
+  c <- cg.sum(cg.pmax(a, cg.as.numeric(b)))
 
   # Calculate gradients
   grads <- gradients(c, run(c))
@@ -164,7 +164,7 @@ test_that("Array [pmin, as.numeric]",
   b <- parm(array(2:7, 2:3), name = "b")
 
   # Create test expression
-  c <- cg.sum(cg.pmin(a, as.numeric(b)))
+  c <- cg.sum(cg.pmin(a, cg.as.numeric(b)))
 
   # Calculate gradients
   grads <- gradients(c, run(c))
